AudioOutputDevice class

音声出力デバイス (スピーカー) の情報です。

Annotations

Properties

deviceId String
音声デバイスの識別子です。
final
hashCode int
The hash code for this object.
no setterinherited
label String
音声デバイスの表示名です。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int?
音声デバイスの種別です。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited