SoraConnectionStateChangedEvent class final
接続状態イベント
- Inheritance
-
- Object
- SoraConnectionEvent
- SoraConnectionStateChangedEvent
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → SoraConnectionState
-
遷移後の接続状態。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited